#!/usr/bin/python

## nfsBackend.py - Contains the backend code needed for redhat-config-nfs
## Copyright (C) 2002 Red Hat, Inc.
## Copyright (C) 2002 Brent Fox <bfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import string
import os
import gtk
import nfsData

class NfsBackend:

    def __init__(self):
        self.entries = []

        self.parseFile()

    def getEntries(self):
        return self.entries

    def printEntries(self):
        for key in self.entries.keys():
            print key, " : ", self.entries[key]
            print "\n"

    def getNfsStatus(self):
        fd = os.popen('/sbin/service nfs status')
        lines = fd.readlines()
        fd.close()

        for line in lines:
            if string.find(line, 'nfsd') >= 0:
#                print line
                if string.find(line, 'stopped') > 0:
#                    print "it's stopped"
                    return gtk.FALSE
                if string.find(line, 'running') > 0:
#                    print "it's running"
                    return gtk.TRUE

    def startNfs(self):
        fd = os.popen('/sbin/service nfs start')
        fd.close()

    def exportFs(self):
        fd = os.popen('/usr/sbin/exportfs -r')
        fd.close()

    def writeFile(self, list):
        os.rename('/etc/exports', '/etc/exports.bak')
        fd = open('/etc/exports', 'w')

        for line in list:
            fd.write(line)

        fd.close()
        
    def parseFile(self):
        fd = open('/etc/exports', 'r')
#        fd = open('exports-test', 'r')
#        fd = open('exports', 'r')
        line = fd.readline()

        entries = {}

        while line:
            if line[0] == '#':
                line = fd.readline()
            else:
                nfsDataObject = nfsData.nfsData()
                
                tokens = string.split(line)

                hostname, options = string.split(tokens[1], "(")
                options = string.replace(options, ")", "")
                optionTokens = string.split(options, ",")

                for token in optionTokens:                    
                    nfsDataObject.set_directory(tokens[0])
                    nfsDataObject.set_hosts(hostname)

                    if token == "ro":
                        nfsDataObject.set_permissions(token)
                    elif token == "rw":
                        nfsDataObject.set_permissions(token)
                    elif token == "insecure":
                        nfsDataObject.set_insecure(token)
                    elif token == "sync" or token == "async":
                        nfsDataObject.set_sync(token)
                    elif token == "no_wdelay":
                        nfsDataObject.set_no_wdelay(token)
                    elif token == "no_subtree_check":
                        nfsDataObject.set_no_subtree_check(token)
                    elif token == "insecure_locks" or token == "no_auth_nlm":
                        nfsDataObject.set_insecure_locks(token)
                    elif token == "no_root_squash":
                        nfsDataObject.set_no_root_squash(token)
                    elif token == "all_squash":
                        nfsDataObject.set_all_squash(token)
                    elif token[:7] == "anonuid":
                        str, uid = string.split(token, "=")
                        nfsDataObject.set_anonuid(uid)
                    elif token[:7] == "anongid":
                        str, gid = string.split(token, "=")
                        nfsDataObject.set_anongid(gid)

                self.entries.append(nfsDataObject)
                line = fd.readline()

        fd.close()
